kooplearn package
=================

Submodules
----------

kooplearn.estimators module
---------------------------

.. automodule:: kooplearn.estimators
   :members:
   :undoc-members:
   :show-inheritance:

kooplearn.kernels module
------------------------

.. automodule:: kooplearn.kernels
   :members:
   :undoc-members:
   :show-inheritance:

kooplearn.utils module
----------------------

.. automodule:: kooplearn.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: kooplearn
   :members:
   :undoc-members:
   :show-inheritance:
